@@ -14,7 +14,7 @@ class TextEntry(EntryBlock):
             'type': 'text',
             'value': {
                 'text': {
-                    'value': txt if txt else eval('self.mocker.' + size),
+                    'value': txt if txt else eval('self.' + size),
                 },
                 'align': align
             }
