@@ -30,6 +30,8 @@ def ico_astro(icons, level):
 
 @register.filter
 def ico_snippet(icon, theme):
+    if not hasattr(icon, theme):
+        theme = 'space'
     doc = eval('icon.%s' % theme)
     if doc:
         return doc.file.url
